@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.97 2007/10/09 16:27:08 albertel Exp $
+# $Id: lonlogin.pm,v 1.98 2008/01/16 20:42:44 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -235,20 +235,6 @@ ENDTROUBLE
 # ----------------------------------------------- Apparently we are in business
     $servadm=~s/\,/\<br \/\>/g;
 
-# --------------------------------------------------- Print login screen header
-    $r->print(<<ENDHEADER);
-<html>
-<head>
-<meta HTTP-EQUIV="Refresh" CONTENT="$expire; url=/adm/roles" />
-<title>The LearningOnline Network with CAPA Login</title>
-</head>
-ENDHEADER
-# ---------------------------------------------------- Serve out DES JavaScript
-    {
-	my $jsh=Apache::File->new($include."/londes.js");
-        $r->print(<$jsh>);
-    }
-
 # ----------------------------------------------------------- Front page design
     my $pgbg=
       ($fullgraph?&Apache::loncommon::designparm('login.pgbg',$domain):'#FFFFFF');
@@ -263,47 +249,28 @@ ENDHEADER
       ($fullgraph?&Apache::loncommon::designparm('login.mainbg',$domain):'#FFFFFF');
     my $sidebg=
       ($fullgraph?&Apache::loncommon::designparm('login.sidebg',$domain):'#FFFFFF');
+    my $textcol = 
+      ($fullgraph?&Apache::loncommon::designparm('login.textcol',$domain):'#000000');
+    my $bgcol =
+      ($fullgraph?&Apache::loncommon::designparm('login.bgcol',$domain):'#FFFFFF');
     my $logo=&Apache::loncommon::designparm('login.logo',$domain);
     my $img=&Apache::loncommon::designparm('login.img',$domain);
     my $domainlogo=&Apache::loncommon::domainlogo($domain);
-    my $showadminmail=&Apache::loncommon::designparm('login.adminmail',                                                      $domain);
+    my $login=&Apache::loncommon::designparm('login.login',$domain);
+    if ($login eq '') {
+        $login = $iconpath.'/'.&mt('userauthentication.gif');
+    }
+    my $showadminmail=&Apache::loncommon::designparm('login.adminmail',$domain);
     my $showcoursecat =
         &Apache::loncommon::designparm('login.coursecatalog',$domain);
-
-
-# ----------------------------------------------------------------------- Texts
-
-my %lt=&Apache::lonlocal::texthash(
-		  'un'  => 'Username',
-		  'pw'  => 'Password',
-		  'dom' => 'Domain',
-		  'perc' => 'percent',
-		  'load' => 'Load',
-                  'userload' => 'User Load',
-                  'about'  => 'About LON-CAPA',
-                  'access' => 'Accessibility Options',
-                  'catalog' => 'Course Catalog',
-		  'auth' => 'userauthentication.gif',
-		  'log' => 'Log in',
-		  'help' => 'Log-in Help',
-		  'serv' => 'Server',
-                  'servadm' => 'Server Administration',
-                  'helpdesk' => 'Contact Helpdesk',
-                  'forgotpw' => 'Forgot password?');
-# -------------------------------------------------- Change password field name
+    my $loginheader =&Apache::loncommon::designparm('login.loginheader',$domain);
     my $now=time;
-    my $forgotpw = &forgotpwdisplay(%lt);
-    my $loginhelp = &loginhelpdisplay(%lt);
-# ---------------------------------------------------------- Serve rest of page
-    $r->print(<<ENDSCRIPT);
-
-<body bgcolor="$pgbg" text="$font" link="$link" vlink="$vlink" alink="$alink"
-  topmargin=0 leftmargin=0 marginwidth=0 marginheight=0>
+    my $js = (<<ENDSCRIPT);
 
  <script language="JavaScript">
     function send()
     {
-	this.document.server.elements.uname.value
+        this.document.server.elements.uname.value
        =this.document.client.elements.uname.value;
 
         this.document.server.elements.udom.value
@@ -332,21 +299,68 @@ my %lt=&Apache::lonlocal::texthash(
         initkeys();
 
         this.document.server.elements.upass0.value
-	    =crypted(this.document.client.elements.upass$now.value.substr(0,15));
-	this.document.server.elements.upass1.value
-	    =crypted(this.document.client.elements.upass$now.value.substr(15,15));
-	this.document.server.elements.upass2.value
-	    =crypted(this.document.client.elements.upass$now.value.substr(30,15));
+            =crypted(this.document.client.elements.upass$now.value.substr(0,15));
+        this.document.server.elements.upass1.value
+            =crypted(this.document.client.elements.upass$now.value.substr(15,15));
+        this.document.server.elements.upass2.value
+            =crypted(this.document.client.elements.upass$now.value.substr(30,15));
 
         this.document.client.elements.uname.value='';
         this.document.client.elements.upass$now.value='';
 
         this.document.server.submit();
-	return false;
+        return false;
     }
  </script>
+
 ENDSCRIPT
 
+# --------------------------------------------------- Print login screen header
+
+    my %add_entries = (topmargin    => "0",
+                       leftmargin   => "0",
+                       marginheight => "0",
+                       marginwidth  => "0",
+                       bgcolor      => "$pgbg",
+                       text         => "$font",
+                       link         => "$link",
+                       vlink        => "$vlink",
+                       alink        => "$alink",);
+
+    $r->print(&Apache::loncommon::start_page('The LearningOnline Network with CAPA Login',$js,
+                                       { 'redirect'       => [$expire,'/adm/roles'], 
+                                         'add_entries' => \%add_entries,
+                                         'only_body'   => 1,}));
+
+# ----------------------------------------------------------------------- Texts
+
+my %lt=&Apache::lonlocal::texthash(
+		  'un'  => 'Username',
+		  'pw'  => 'Password',
+		  'dom' => 'Domain',
+		  'perc' => 'percent',
+		  'load' => 'Load',
+                  'userload' => 'User Load',
+                  'about'  => 'About LON-CAPA',
+                  'access' => 'Accessibility Options',
+                  'catalog' => 'Course Catalog',
+		  'log' => 'Log in',
+		  'help' => 'Log-in Help',
+		  'serv' => 'Server',
+                  'servadm' => 'Server Administration',
+                  'helpdesk' => 'Contact Helpdesk',
+                  'forgotpw' => 'Forgot password?');
+# -------------------------------------------------- Change password field name
+    my $forgotpw = &forgotpwdisplay(%lt);
+    my $loginhelp = &loginhelpdisplay(%lt);
+
+# ---------------------------------------------------- Serve out DES JavaScript
+    {
+        my $jsh=Apache::File->new($include."/londes.js");
+        $r->print(<$jsh>);
+    }
+# ---------------------------------------------------------- Serve rest of page
+
     if ($fullgraph) {
 	$r->print(
 		  '<table width="100%" cellpadding=0 cellspacing=0 border=0>');
@@ -463,13 +477,20 @@ ENDACCESSOPTIONS
 <input type="hidden" name="remember"  value="" />
 ENDNOOPT
 }
+    my $logintitle;
+    if ($loginheader eq 'text') {
+        $logintitle = '<td bgcolor="'.$bgcol.'" colspan="2">&nbsp;&nbsp;&nbsp;<b><font size="+1" color="'.$textcol.'">'.$lt{'log'}.'</font></b></td>';
+    } else {
+        $logintitle = '<td bgcolor="'.$sidebg.'" colspan="2"><img src="'.$login.'" alt="'.
+                      &mt('User Authentication').'" /></td>';
+    }
     $r->print(<<ENDLOGIN);
      <input type="hidden" name="lextkey" value="$lextkey">
      <input type="hidden" name="uextkey" value="$uextkey">
 
      <!-- Start the sub-table for text and input alignment -->
      <table border=0 cellspacing=0 cellpadding=0>
-      <tr><td bgcolor="$sidebg" colspan=2><img src="$iconpath/$lt{'auth'}" alt="User Authentication" /></td></tr>
+      <tr>$logintitle</tr>
       <tr>
        <td bgcolor="$mainbg"><br /><font size=-1><b>&nbsp;&nbsp;&nbsp;<label for="uname">$lt{'un'}</label>:</b></font></td>
        <td bgcolor="$mainbg"><br /><input type="text" name="uname" size="10" value="$authusername" /></td>
@@ -593,7 +614,8 @@ $helpdeskscript
 
 ENDDOCUMENT
 }
-    $r->print('</body></html>');
+    my %endargs = ( 'noredirectlink' => 1, );
+    $r->print(&Apache::loncommon::end_page(\%endargs));
     return OK;
 }
 
