@@ -1,5 +1,5 @@
 # Automated Enrollment manager
-# $Id: Enrollment.pm,v 1.36 2007/08/03 22:02:01 albertel Exp $
+# $Id: Enrollment.pm,v 1.37 2007/12/23 02:48:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -684,7 +684,7 @@ sub execute_add {
         $changeHash{'permanentemail'} = $emailenc;
         my $putresult = &Apache::lonnet::put('environment',\%changeHash,$dom,$uname);
         if ($putresult eq 'ok') {
-            $$logmsg .= &mt('User information updated for user: [_1]$uname prior to enrollment.',$uname).$linefeed;
+            $$logmsg .= &mt('User information updated for user: [_1] prior to enrollment.',$uname).$linefeed;
         } else {
             $$logmsg .= &mt('There was a problem modifying user data for existing user - [_1] -error: [_2], enrollment will still be attempted.',$uname,$putresult).$linefeed;
         }
