@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.112 2007/10/03 00:24:48 albertel Exp $
+# $Id: edit.pm,v 1.113 2008/01/15 03:09:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -577,7 +577,8 @@ sub element_change_detection {
 }
 
 sub submit_ask_anyway {
-    return ' onclick="still_ask=true;" ';
+    my ($extra_action) = @_;
+    return ' onclick="still_ask=true;'.$extra_action.'" ';
 }
 
 sub textarea_sizes {
