@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # external style responses
 #
-# $Id: externalresponse.pm,v 1.7 2007/04/18 00:19:37 albertel Exp $
+# $Id: externalresponse.pm,v 1.12 2007/10/15 09:47:29 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -37,13 +37,31 @@ BEGIN {
 }
 
 #FIXME
-# send of response params and there current values
-# accept a string to be printed out (Where does it get shown?) (.message)
-# need to get a correct answer from somewhere (probably here since randomized)
+# send of response params and their current values (form good enough?
+# what parameters to send?)
+# Need to get returned message displayed 
 sub start_externalresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
     my $id = &Apache::response::start_response($parstack,$safeeval);
+
+    if ($target eq 'edit') {
+  	$result .=&Apache::edit::tag_start($target,$token);
+	$result .=&Apache::edit::text_arg('URL:','url',$token,60).'<br />';
+	$result .=&Apache::edit::text_arg('Answer:','answer',$token);
+	$result .=&Apache::edit::text_arg('Form:','form',$token);
+	$result .=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+	my $constructtag =
+	    &Apache::edit::get_new_args($token,$parstack,$safeeval,
+					'answer','form','url');
+	if ($constructtag) {
+	    $result = &Apache::edit::rebuild_tag($token);
+	}
+    } elsif ($target eq 'meta') {
+  	$result=&Apache::response::meta_package_write('externalresponse');
+    }
+    
     return $result;
 }
 
@@ -74,11 +92,12 @@ sub end_externalresponse {
 								     $part,$id);
 		%Apache::loncapagrade::results=();
 		$Apache::lonhomework::results{"resource.$part.$id.submission"}=$response;
-		if ($res->{_rc} != '200') {
+		if ($res->is_error()) {
 		    $Apache::loncapagrade::results{'awarddetail'}='ERROR';
 		} else {
 		    &Apache::lonxml::register('Apache::loncapagrade',
 					      ('loncapagrade'));
+		    @Apache::scripttag::parser_env = @_;
 		    my $result=&Apache::scripttag::xmlparse($res->{_content});
 		    &Apache::lonxml::debug("Got a result of :$result:");
 		}
@@ -103,7 +122,11 @@ sub end_externalresponse {
 
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' ||
 	$target eq 'tex' || $target eq 'analyze') {
-	&Apache::lonxml::increment_counter($increment);
+	&Apache::lonxml::increment_counter($increment, "$part.$id");
+
+	if ($target eq 'analyze') {
+	    &Apache::lonhomework::set_bubble_lines();
+	}
     }
     &Apache::response::end_response();
     return $result;
