@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.235 2007/11/17 02:03:46 albertel Exp $
+# $Id: inputtags.pm,v 1.236 2008/01/14 14:32:14 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -636,8 +636,8 @@ sub decideoutput {
 	  );
 
     my $part = $Apache::inputtags::part;
-    my $handgrade = 
-	('yes' eq lc(&Apache::lonnet::EXT("resource.$part.handgrade")));
+    my $tohandgrade = &Apache::lonnet::EXT("resource.$part.handgrade");
+    my $handgrade = ('yes' eq lc($tohandgrade)); 
     
     my $computer = ($handgrade)? ''
 	                       : " ".&mt("Computer's answer now shown above.");
