@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # mutliple choice style responses
 #
-# $Id: radiobuttonresponse.pm,v 1.125 2007/08/06 20:52:54 albertel Exp $
+# $Id: radiobuttonresponse.pm,v 1.130 2007/10/22 09:29:58 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -18,8 +18,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LON-CAPA; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with LON-CAPA; if not, write to the Free Software# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # /home/httpd/html/adm/gpl.txt
 #
@@ -56,8 +55,6 @@ sub start_radiobuttonresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
 
-
-
     #when in a radiobutton response use these
     &Apache::lonxml::register('Apache::radiobuttonresponse',('foilgroup','foil','conceptgroup'));
     push (@Apache::lonxml::namespace,'radiobuttonresponse');
@@ -202,7 +199,8 @@ sub end_foilgroup {
     my $bubble_lines;
     my $bubbles_per_line;
     my $answer_count;
-    my $id = $Apache::inputtags::response['-1'];
+    my $id   = $Apache::inputtags::response['-1'];
+    my $part = $Apache::inputtags::part;
     $bubbles_per_line = 
 	&Apache::response::get_response_param($Apache::inputtags::part."_$id",
 					      'numbubbles',
@@ -244,11 +242,14 @@ sub end_foilgroup {
 	    } elsif ( $target eq 'grade') {
 		&grade_response($answer, \@shown, $bubbles_per_line);
 	    }  elsif ( $target eq 'analyze') {
+		my $bubble_lines = &bubble_line_count($answer_count, 
+						      $bubbles_per_line);
 		&Apache::response::analyze_store_foilgroup(\@shown,
 							   ['text','value','location']);
-		my $part_id="$Apache::inputtags::part.$Apache::inputtags::response[-1]";
+		my $part_id="$part.$id";
 		push (@{ $Apache::lonhomework::analyze{"$part_id.options"} },
 		      ('true','false'));
+
 	    }
 	}
 	$Apache::lonxml::post_evaluate=0;
@@ -257,9 +258,13 @@ sub end_foilgroup {
 	&Apache::response::setup_prior_tries_hash(\&format_prior_answer,
 						  [\%Apache::response::foilgroup]);
     }
-    $bubble_lines = &bubble_line_count($answer_count, $bubbles_per_line);
     &Apache::response::poprandomnumber();
-    &Apache::lonxml::increment_counter($bubble_lines);
+    $bubble_lines = &bubble_line_count($answer_count, $bubbles_per_line);
+    &Apache::lonxml::increment_counter($bubble_lines,
+				       "$part.$id");
+    if ($target eq 'analyze') {
+	&Apache::lonhomework::set_bubble_lines();
+    }
     return $result;
 }
 
