@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # rank style response
 #
-# $Id: rankresponse.pm,v 1.52 2007/04/17 23:25:09 albertel Exp $
+# $Id: rankresponse.pm,v 1.55 2007/10/15 09:47:29 foxr Exp $
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -67,6 +67,8 @@ sub start_rankresponse {
     } elsif ($target eq 'analyze') {
 	my $part_id="$Apache::inputtags::part.$id";
 	push (@{ $Apache::lonhomework::analyze{"parts"} },$part_id);
+	push (@{ $Apache::lonhomework::analyze{"$part_id.bubble_lines"} }, 1);
+
     }
     return $result;
 }
@@ -118,7 +120,13 @@ sub end_foilgroup {
 		"$Apache::inputtags::part.$Apache::inputtags::response[-1]";
 	    $Apache::lonhomework::analyze{"$part_id.tol"}=$tol;
 	}
-	&Apache::lonxml::increment_counter(&getfoilcounts($max));
+	my $part = $Apache::inputtags::part;
+	my $id   = $Apache::inputtags::response[-1];
+	&Apache::lonxml::increment_counter(&getfoilcounts($max),
+					   "$part.$id");
+	if ($target eq 'analyze') {
+	    &Apache::lonhomework::set_bubble_lines();
+	}
     } elsif ($target eq 'edit') {
 	$result=&Apache::edit::end_table();
     }
