@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.414 2007/11/20 17:53:22 albertel Exp $
+# $Id: structuretags.pm,v 1.416 2008/01/15 03:09:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -94,6 +94,7 @@ sub end_tex {
 
 sub homework_js {
     return &Apache::loncommon::resize_textarea_js().
+           &setmode_javascript().
 	<<'JS';
 <script type="text/javascript">
 function setSubmittedPart (part) {
@@ -113,10 +114,22 @@ function image_response_click (which, e) {
     input_element.value = click;
     img_element.src = '/adm/randomlabel.png?token='+token+'&clickdata='+click;
 }
+
 </script>
 JS
 }
 
+sub setmode_javascript {
+    return <<"ENDSCRIPT";
+<script type="text/javascript">
+function setmode(form,probmode) {
+    form.problemmode.value = probmode;
+    form.submit();
+}
+</script>
+ENDSCRIPT
+}
+
 sub page_start {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$name,
 	$extra_head)=@_;
@@ -307,14 +320,15 @@ sub problem_edit_header {
 '.&mt('Problem Editing').&Apache::loncommon::help_open_menu('Problem Editing','Problem_Editor_XML_Index',5,'Authoring').'
 </div>
 <div class="LC_edit_problem_discards">
-       <input type="hidden" name="problemmode" value="'.&mt('Edit').'" />
-       <input type="submit" name="problemmode" accesskey="d" value="'.&mt('Discard Edits and View').'" />
-       <input '.&Apache::edit::submit_ask_anyway().' type="submit" name="problemmode" accesskey="x" value="'.&mt('EditXML').'" />
+       <input type="hidden" name="problemmode" value="edit" />
+       <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
+       ' onclick="javscript:setmode(this.form,'."'discard.'".')"  />
+       <input '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'editxml'".')').' type="button" name="submitmode" accesskey="x" value="'.&mt('EditXML').'" />
        <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
 </div>
 <div class="LC_edit_problem_saves">
-       <input type="submit" name="submit" accesskey="s" value="'.&mt('Save and Edit').'" />
-       <input type="submit" name="submit" accesskey="v" value="'.&mt('Save and View').'" />
+       <input type="submit" name="submitbutton" accesskey="s" value="'.&mt('Save and Edit').'" />
+       <input type="submit" name="submitbutton" accesskey="v" value="'.&mt('Save and View').'" />
   </div>
 <hr class="LC_edit_problem_divide" />
 '.&Apache::lonxml::message_location().'
@@ -328,13 +342,14 @@ sub problem_edit_footer {
 <div class="LC_edit_problem_footer">
   <hr class="LC_edit_problem_divide" />
   <div class="LC_edit_problem_discards">
-     <input type="submit" name="problemmode" accesskey="d" value="'.&mt('Discard Edits and View').'" />
-     <input '.&Apache::edit::submit_ask_anyway().' type="submit" name="problemmode" accesskey="x" value="'.&mt('EditXML').'" />
+     <input type="button" name="submitmode" accesskey="d" value="'.&mt('Discard Edits and View').'" '.
+     'onclick=javascript:setmode(this.form,'."'discard'".')" />
+     <input '.&Apache::edit::submit_ask_anyway('setmode(this.form,'."'editxml'".')').' type="button" name="submitmode" accesskey="x" value="'.&mt('EditXML').'" />
      <input type="submit" name="Undo" accesskey="u" value="'.&mt('undo').'" />
   </div>
   <div class="LC_edit_problem_saves">
-    <input type="submit" name="submit" value="'.&mt('Save and Edit').'" />
-    <input type="submit" name="submit" value="'.&mt('Save and View').'" />
+    <input type="submit" name="submitbutton" value="'.&mt('Save and Edit').'" />
+    <input type="submit" name="submitbutton" value="'.&mt('Save and View').'" />
   </div>
   <hr class="LC_edit_problem_divide" />
 </div>
@@ -461,8 +476,9 @@ $show_all
 	if (!$numtoanalyze) { $numtoanalyze=20; }
 	$result .= '<span class="LC_nobreak">'.
 	    &mt('[_1] for [_2] versions.',
-		'<input type="submit" name="problemmode" value='.&mt('"Calculate answers').'" />',
-		'<input type="text" name="numtoanalyze" value="'.
+		'<input type="button" name="submitmode" value="'.&mt('Calculate answers').'" '.
+                'onclick="javascript:setmode(this.form,'."'calcanswers'".')" />
+		<input type="text" name="numtoanalyze" value="'.
 		$numtoanalyze.'" size="5" />').
 		&Apache::loncommon::help_open_topic("Analyze_Problem",'',undef,undef,300).
 		'</span>';
@@ -472,9 +488,11 @@ $show_all
     $result.='
    </div>
    <div class="LC_edit_problem_header_edit_row">';
-    $result.='<input type="hidden" name="problemmode" value="'.&mt('View').'" />';
-    $result .= '<input type="submit" name="problemmode" accesskey="e" value="'.&mt('Edit').'" />';
-    $result .= '<input type="submit" name="problemmode" accesskey="x" value="'.&mt('EditXML').'" />';
+    $result.='<input type="hidden" name="problemmode" value="view" />';
+    $result .= '<input type="button" name="submitmode" accesskey="e" value="'.&mt('Edit').'" '.
+               'onclick="javascript:setmode(this.form,'."'edit'".')" />';
+    $result .= '<input type="button" name="submitmode" accesskey="x" value="'.&mt('EditXML').'" '.
+               'onclick="javascript:setmode(this.form,'."'editxml'".')" />';
     $result.='
    </div>
    '.&Apache::lonxml::message_location().'
@@ -754,7 +772,8 @@ sub start_problem {
     }
 
     if ($target ne 'analyze') {
-	$Apache::lonhomework::type=&Apache::lonnet::EXT('resource.0.type');
+        my $type = &Apache::lonnet::EXT('resource.0.type');
+	$Apache::lonhomework::type=$type;
 	if (($env{'request.state'} eq 'construct') &&
 	    $env{'form.problemtype'} =~ /\S/) {
 	    $Apache::lonhomework::type=$env{'form.problemtype'};
