@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.24 2007/12/10 23:54:40 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.25 2008/01/12 22:32:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -496,7 +496,12 @@ sub construct_data_table {
         } elsif ($env{'form.sortby'} eq 'owner') {
             push(@{$Sortby{$courseinfo{$course}{'ownerlastnames'}}},$course);
         } else {
-            push(@{$Sortby{$courseinfo{$course}{'title'}}},$course);
+            my $clean_title = $courseinfo{$course}{'title'};
+            $clean_title =~ s/\W+//g;
+            if ($clean_title eq '') {
+                $clean_title = $courseinfo{$course}{'title'};
+            }
+            push(@{$Sortby{$clean_title}},$course);
         }
     }
     my @sorted_courses;
