@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # routines for clone a course
 #
-# $Id: lonclonecourse.pm,v 1.3 2007/08/02 01:34:07 albertel Exp $
+# $Id: lonclonecourse.pm,v 1.4 2008/01/18 17:51:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -115,7 +115,9 @@ sub copyfile {
        '/uploaded/'.$origcrsdata{'domain'}.'/'.$origcrsdata{'num'}.'/'
     => '/uploaded/'. $newcrsdata{'domain'}.'/'. $newcrsdata{'num'}.'/',
        '/public/'.$origcrsdata{'domain'}.'/'.$origcrsdata{'num'}.'/'
-    => '/public/'. $newcrsdata{'domain'}.'/'. $newcrsdata{'num'}.'/'
+    => '/public/'. $newcrsdata{'domain'}.'/'. $newcrsdata{'num'}.'/',
+       '/adm/'.$origcrsdata{'domain'}.'/'.$origcrsdata{'num'}.'/'
+    => '/adm/'.$newcrsdata{'domain'}.'/'.$newcrsdata{'num'}.'/',
             )));
     }
 }
