@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.104.2.1 2007/11/28 17:36:11 albertel Exp $
+# $Id: loncreatecourse.pm,v 1.104.2.2 2007/12/23 17:36:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -35,7 +35,7 @@ use Apache::lonnet;
 use Apache::loncommon;
 use Apache::londocs;
 use Apache::lonlocal;
-use Apache::londropadd;
+use Apache::lonuserutils;
 use Apache::lonclonecourse;
 use LONCAPA::batchcreatecourse;
 use LONCAPA;
@@ -71,13 +71,13 @@ sub print_course_creation_page {
     if ($crstype eq 'Course') {
         my $starttime = time;
         my $endtime = time+(6*30*24*60*60); # 6 months from now, approx
-        $enroll_table = &Apache::londropadd::date_setting_table($starttime,
+        $enroll_table = &Apache::lonuserutils::date_setting_table($starttime,
                                                 $endtime,'create_enrolldates');
-        $access_table = &Apache::londropadd::date_setting_table($starttime,
+        $access_table = &Apache::lonuserutils::date_setting_table($starttime,
                                                $endtime,'create_defaultdates');
         ($krbdef,$krbdefdom) =
         &Apache::loncommon::get_kerberos_defaults($defdom);
-        $javascript_validations=&Apache::londropadd::javascript_validations(
+        $javascript_validations=&Apache::lonuserutils::javascript_validations(
                                                     'createcourse',$krbdefdom);
         my %param = ( formname      => 'document.ccrs',
                       kerb_def_dom  => $krbdefdom,
