@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.171 2007/11/17 01:46:03 albertel Exp $
+# $Id: lonhtmlcommon.pm,v 1.172 2008/01/15 03:42:35 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1235,16 +1235,19 @@ returns: nothing
 	if (!defined($menulink)) { $menulink=1; }
         if ($menulink) {
             my $description = 'Menu';
+            my $no_mt_descr = 0;
             if (exists($env{'request.course.id'}) && 
                 $env{'request.course.id'} ne '') {
                 $description = 
                     $env{'course.'.$env{'request.course.id'}.'.description'};
+                $no_mt_descr = 1;
             }
             unshift(@Crumbs,{
                     href   =>'/adm/menu',
                     title  =>'Go to main menu',
                     target =>'_top',
                     text   =>$description,
+                    no_mt  =>$no_mt_descr,
                 });
         }
         my $links .= 
