@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.231 2007/11/09 20:57:29 albertel Exp $
+# $Id: lonmenu.pm,v 1.233 2008/01/15 16:53:27 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -349,16 +349,18 @@ sub innerregister {
 	} else {
 	    $newmail= 'swmenu.setstatus("you have","messages");';
 	}
-    } elsif (($textual) 
+    } 
+    if (($textual) 
 	     && ($env{'request.symb'}) 
 	     && ($env{'request.course.id'})) {
 	$newmail.= '<td class="LC_current_location">';
 	my ($mapurl,$rid,$resurl)=
 	    &Apache::lonnet::decode_symb(&Apache::lonnet::symbread());
-        $newmail.=$env{'course.'.$env{'request.course.id'}.'.description'};
+        my $coursetitle=$env{'course.'.$env{'request.course.id'}.'.description'};
+        $newmail.=$coursetitle;
         my $maptitle=&Apache::lonnet::gettitle($mapurl);
 	my $restitle=&Apache::lonnet::gettitle(&Apache::lonnet::symbread());
-        if ($maptitle && $maptitle ne 'default.sequence') {
+        if ($maptitle && ($maptitle ne 'default.sequence') && ($maptitle ne $coursetitle)) {
 	    $newmail.=', '.$maptitle;
         }
         if ($restitle) {
@@ -1398,7 +1400,8 @@ sub hidden_button_check {
     if ($env{'request.role.adv'}) {
         return;
     }
-    return &Apache::lonnet::EXT('resource.0.buttonshide'); 
+    my $buttonshide = &Apache::lonnet::EXT('resource.0.buttonshide');
+    return $buttonshide; 
 }
 
 # ================================================================ Main Program
