@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.208 2007/05/15 20:21:17 albertel Exp $
+# $Id: lonmeta.pm,v 1.209 2007/06/15 23:01:07 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1312,6 +1312,11 @@ ENDEDIT
 		$Apache::lonpublisher::metadatafields{'owner'} =
 		    $env{'user.name'}.':'.$env{'user.domain'};
 	    }
+	    if (! $Apache::lonpublisher::metadatafields{'author'}) {
+		$Apache::lonpublisher::metadatafields{'author'} =
+		    &Apache::loncommon::plainname($env{'user.name'},
+						  $env{'user.domain'});
+	    }
 	    if ($Apache::lonpublisher::metadatafields{'courserestricted'} ne 'none') {
 
                 if ($file_type eq 'portfolio') {
