@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.52 2007/09/10 19:22:22 raeburn Exp $
+# $Id: lonsimplepage.pm,v 1.53 2008/01/18 16:41:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -286,7 +286,8 @@ sub handler {
 		      '<h3>Upload a Photo</h3>'.
 		      '<input type="file" name="uploaddoc" size="50" />'.
 		      '<input type="submit" name="storeupl" value="Upload" />'.
-		      '</form><form method="post">');
+		      '</form><form method="post">'.
+                      '<input type="hidden" name="forceedit" value="edit" />');
 	}
 	foreach my $field (sort(keys(%syllabusfields))) {
 	    if (($syllabus{$field}) || ($allowed) || 
