@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.72 2007/06/06 17:35:32 albertel Exp $
+# $Id: lonwhatsnew.pm,v 1.73 2007/09/26 12:34:19 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -99,28 +99,28 @@ sub handler {
               text=>"Display Action Items"});
     if (($command eq 'chgthreshold') && $checkallowed{'abovethreshold'}) {
         &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>'/adm/whatsnew?command=chgthreshold&refpage='.$refpage,
+            ({href=>'/adm/whatsnew?command=chgthreshold&amp;refpage='.$refpage,
               text=>"Change thresholds"});
         $r->print(&Apache::lonhtmlcommon::breadcrumbs
             ("What's New?",#'Course_Action_Items_Thresholds'
 	     ));
     } elsif (($command eq 'chginterval') && $checkallowed{'versionchanges'} ) {
         &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>'/adm/whatsnew?command=chginterval&refpage='.$refpage,
+            ({href=>'/adm/whatsnew?command=chginterval&amp;refpage='.$refpage,
               text=>"Change interval"});
         $r->print(&Apache::lonhtmlcommon::breadcrumbs
             ("What's New?",#'Course_Action_Items_Intervals'
 	     ));
     } elsif (($command eq 'chgdisc') && $checkallowed{'coursediscussion'}) {
         &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>'/adm/whatsnew?command=chgdisc&refpage='.$refpage,
+            ({href=>'/adm/whatsnew?command=chgdisc&amp;refpage='.$refpage,
               text=>"Change discussion display"});
         $r->print(&Apache::lonhtmlcommon::breadcrumbs
             ("What's New?",#'Course_Action_Items_Intervals'
 	     ));
     } elsif ($command eq 'courseinit') {
         &Apache::lonhtmlcommon::add_breadcrumb
-            ({href=>'/adm/whatsnew?command=courseinit&refpage='.$refpage,
+            ({href=>'/adm/whatsnew?command=courseinit&amp;refpage='.$refpage,
               text=>"Course initialization preference"});
         $r->print(&Apache::lonhtmlcommon::breadcrumbs
             ("What's New?",#'Course_Action_Items_Initialization'
@@ -295,7 +295,7 @@ sub display_actions_box {
     my $currinit = $pagedesc{$initdisp}.' ('.$pagedesc{$initcontrol}.')';
 
     unless ($cid) {
-        $r->print('<br /><b><center>'.$lt{'yacc'}.'</center></b><br /><br />');
+        $r->print('<p><span style="text-align: center; font-weight: bold;">'.$lt{'yacc'}.'</span></p>');
         return;
     }
 
@@ -304,14 +304,14 @@ sub display_actions_box {
             &GDBM_READER(),0640)) {
             my $furl=$bighash{'first_url'};
             untie(%bighash);
-            $r->print('<font size="+1"><a href="'.$furl.'">'.$lt{'gtfr'}.
-                  '</a></font><br />');
+            $r->print('<span style="font-size: larger;"><a href="'.$furl.'">'.$lt{'gtfr'}.
+                  '</a></span><br />');
         }
     }
     $r->print(&mt('Page set to be displayed after you have selected a role in this '.$lctype).
-              '. <nobr>'.&mt('Currently: <i>[_1]</i>',$currinit).'.&nbsp;&nbsp;'.
-              &mt('<b>Change</b> for just <a href="/adm/whatsnew?command=courseinit&refpage=[_1]">this '.$lctype.'</a>',$refpage).' '.
-              &mt('or for all <a href="/adm/preferences?action=changecourseinit&refpage=[_1]">your courses</a>.',$refpage).'</nobr><br /><hr />');
+              '. <span class="LC_nobreak">'.&mt('Currently: <i>[_1]</i>',$currinit).'.&nbsp;&nbsp;'.
+              &mt('<b>Change</b> for just <a href="/adm/whatsnew?command=courseinit&amp;refpage=[_1]">this '.$lctype.'</a>',$refpage).' '.
+              &mt('or for all <a href="/adm/preferences?action=changecourseinit&amp;refpage=[_1]">your courses</a>.',$refpage).'</span><br /><hr />');
 
     if ($command eq 'reset') {
         $result = &process_reset($cdom,$crs);
@@ -411,7 +411,7 @@ sub display_actions_box {
         }
     }
 
-    $r->print('<input type="hidden" name="refpage" value="'.$refpage.'"></form><br /><table border="0" width="100%" cellpadding="2" cellspacing="4"><tr><td align="left" valign="top" width="45%">');
+    $r->print('<input type="hidden" name="refpage" value="'.$refpage.'" /></form><table class="LC_double_column"><tr><td class="LC_left_col">');
 
     my $displayed = 0;
     my $totalboxes = 0;
@@ -426,20 +426,17 @@ sub display_actions_box {
     foreach my $actionitem (@actionorder) {
         if ($$checkallowed{$actionitem}) {
             if ($displayed == $halfway) {
-                $r->print('</td><td width="6%">&nbsp;</td><td align="left" valign="top" width="47%">');
+                $r->print('</td><td>&nbsp;</td><td class="LC_right_col" >');
             }
             &display_launcher($r,$actionitem,$refpage,$checkallowed,\%show,\%headings,\%res_title,\@tograde,\%ungraded,\@bombs,\%bombed,\%changed,\@warnings,\%triggered,\@newdiscussions,\%unread,$msgcount,\@newmsgs,$critmsgcount,\@critmsgs,$interval,$countunread);
             $displayed ++; 
         }
     }
     $r->print('
-           </table>
-          </td>
-         </tr>
-        </table>
       </td>
     </tr>
-   </table>');
+   </table>
+');
 }
 
 #-------------------------------
@@ -612,9 +609,9 @@ END
         if ($choice eq $control) {
             $chkstring = ' checked="checked" ';
         }  
-        $r->print('<nobr><label><input type="radio" name="courseinit_control" value="'.
+        $r->print('<span class="LC_nobreak"><label><input type="radio" name="courseinit_control" value="'.
                    $choice.'"'.$chkstring.'/>'.$$initpage{$choice}.
-                   '&nbsp;&nbsp;</label></nobr>');
+                   '&nbsp;&nbsp;</label></span>');
     }
     $r->print('<br /><br />'.&mt('If').' '.$$initpage{'coursespecific'}.
               ' - <br />'.$lt{'chce'}.": \n");
@@ -623,9 +620,9 @@ END
         if (($choice eq $current) && ($control eq 'coursespecific')) {
             $chkstring = ' checked="checked" ';
         }
-        $r->print('<nobr><label><input type="radio" name="courseinit_page" value="'.
+        $r->print('<span class="LC_nobreak"><label><input type="radio" name="courseinit_page" value="'.
                   $choice.'"'.$chkstring.'/>'.$$initpage{$choice}.
-                  '&nbsp;&nbsp;</label></nobr>');
+                  '&nbsp;&nbsp;</label></span>');
     }
     $r->print('<br /><br /><input type="submit" name="display" value="'.
                $lt{'moce'}.'" /></form>');
@@ -1526,7 +1523,7 @@ sub start_box {
     $r->print('
          <table class="LC_nested_outer">
           <tr>
-           <th>'.$$heading{$caller}.'</th>
+           <th class="LC_left_item">'.$$heading{$caller}.'</th>
            <th class="LC_right_item">'.$showhide.'</th>
           </tr>');
      if (($caller eq 'abovethreshold') && ($$show{$caller})) {
