@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.145 2007/10/03 17:39:13 albertel Exp $
+# $Id: lonstudentassessment.pm,v 1.146 2007/12/20 13:57:13 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -372,7 +372,7 @@ sub CreateInterface {
     $Str .= '&nbsp;'x5;
     $Str .= 
         &mt('Status [_1]',
-            '<input type="text" name="stats_status" size="60" value="" />');
+            '<input type="text" name="stats_status" size="60" value="" readonly="readonly" />');
     $Str .= '<br />';
     return $Str;
 }
@@ -671,9 +671,10 @@ sub html_initialize {
     # If we're showing links, show a checkbox to open in new
     # windows.
     if ($show_links ne 'no') {
+        my $labeltext = &mt('Show links in new window:');
         $r->print(<<NEW_WINDOW_CHECKBOX);
 <script type="text/javascript">new_window = true;</script>
-<p><label>Show links in new window: 
+<p><label>$labeltext 
 <input type="checkbox" checked="1" onclick="new_window=this.checked" />
 </label></p>
 NEW_WINDOW_CHECKBOX
@@ -684,7 +685,7 @@ NEW_WINDOW_CHECKBOX
               "&nbsp;&nbsp;".localtime(time)."</h3>");
     #
     if ($chosen_output->{'base'} !~ /^final table/) {
-        $r->print("<h3>".$chosen_output->{'shortdesc'}."</h3>");        
+        $r->print("<h3>".&mt($chosen_output->{'shortdesc'})."</h3>");        
     }
     my $Str = "<pre>\n";
     # First, the @StudentData fields need to be listed
