@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.84.2.1 2007/09/26 00:34:31 albertel Exp $
+# $Id: lonpage.pm,v 1.87 2007/11/30 19:14:14 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -78,7 +78,7 @@ sub tracetable {
                     my $frid=$hash{'map_finish_'.$hash{'src_'.$rid}};
 	            $sofar=
                        &tracetable($sofar,$hash{'map_start_'.$hash{'src_'.$rid}},
-                       '&'.$frid.'&');
+                       '&'.$frid.$beenhere);
                     $sofar++;
                     if ($hash{'src_'.$frid}) {
                         my $brepriv=&Apache::lonnet::allowed('bre',$hash{'src_'.$frid});
@@ -378,12 +378,13 @@ sub handler {
 			  $r->send_http_header;
 # ------------------------------------------------------------------------ Head
 			  if ($allscript) {
-			      $allscript .= 
-				  "\n<script type=\"text/javascript\">\n".
-				  $allscript."\n</script>\n";
+			      $allscript = 
+				  "\n".'<script type="text/javascript">'."\n".
+				  $allscript.
+				  "\n</script>\n";
 			  }
 # ------------------------------------------------------------------ Start body
-			  $r->print(&Apache::loncommon::start_page(undef,undef,
+			  $r->print(&Apache::loncommon::start_page(undef,$allscript,
 								   {'force_register' => 1,
 								    'bgcolor'        => '#ffffff',}));
 # ------------------------------------------------------------------ Start form
