@@ -2,7 +2,7 @@
 #
 # Sequence Handler
 #
-# $Id: lonsequence.pm,v 1.31 2007/07/11 23:51:02 albertel Exp $
+# $Id: lonsequence.pm,v 1.32 2007/12/01 01:59:54 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -46,10 +46,10 @@ my $successtied;
 # ----------------------------------------- Attempt to read from resource space
 
 sub attemptread {
-    my $fn=shift;
+    my ($fn,$unsorted)=@_;
     &Apache::lonnet::repcopy($fn);
     if (-e $fn) {
-	return &LONCAPA::map::attemptread($fn);
+	return &LONCAPA::map::attemptread($fn,$unsorted);
     } else {
         return ();
     }
